@@ -1,14 +1,14 @@
 __author__ = "Rashtrapathy"
 __copyright__ = "Copyright (c) 2018-2021 by Iotium, Inc."
 __license__ = "All rights reserved."
-__version__ = "21.09.15"
+__version__ = "21.10.04"
 __credits__ = ["Rashtrapathy", "Thyagarajan", "Jawahar", "Venkatesan", "Raja"]
 __maintainer__ = "Rashtrapathy"
 __email__ = "rashtrapathy.c@iotium.io"
 __status__ = "Development"
 __name__ = "iotiumlib"
 
-from .node import getv2, get, delete, add, edit, reboot, notifications
+from .node import getv2, get, delete, add, edit, reboot, notifications, upgrade
 from .network import get, getv2, add, edit, delete, resetcounter
 from .firewall import getv2, get, add, edit, delete
 from .pki import get, getv2
