@@ -244,6 +244,11 @@ class resourcePaylod(object):
                 setattr(containerTimeZoneObj, 'container_timezone', payload['container_timezone'])
                 self.container_timezone = getattr(containerTimeZoneObj, 'container_timezone')
 
+            upgradePolicyObj = resourcePaylod.UpgradePolicy.Channel()
+            if 'policy' in payload and payload['policy'] is not None:
+                setattr(upgradePolicyObj, 'policy', payload['policy'])
+                self.channel = getattr(upgradePolicyObj, 'policy')
+
         class nodeName(object):
             def __init__(self):
                 self._nodeName = str()
@@ -1451,6 +1456,16 @@ class resourcePaylod(object):
                 setattr(cluster_Obj, 'cluster', payload['cluster'])
                 self.cluster = getattr(cluster_Obj, 'cluster')
 
+            inode_hw_monitoring_Obj = resourcePaylod.OrgPolicy.HwMonitoring()
+            if 'inode_hw_monitoring' in payload and payload['inode_hw_monitoring'] is not None:
+                setattr(inode_hw_monitoring_Obj, 'inode_hw_monitoring', payload['inode_hw_monitoring'])
+                self.inode_hw_monitoring = getattr(inode_hw_monitoring_Obj, 'inode_hw_monitoring')
+
+            cli_config_rollback_Obj = resourcePaylod.OrgPolicy.CliConfigRollBack()
+            if 'cli_config_rollback' in payload and payload['cli_config_rollback'] is not None:
+                setattr(cli_config_rollback_Obj, 'cli_config_rollback', payload['cli_config_rollback'])
+                self.cli_config_rollback = getattr(cli_config_rollback_Obj, 'cli_config_rollback')
+
         class TOTP(object):
             def __init__(self):
                 self._value = {"enable" : bool()}
@@ -1550,6 +1565,30 @@ class resourcePaylod(object):
             def cluster(self, value):
                 self._value["enable"] = value
 
+        class HwMonitoring(object):
+            def __init__(self):
+                self._value = {"enable" : bool()}
+
+            @property
+            def inode_hw_monitoring(self):
+                return self._value
+
+            @inode_hw_monitoring.setter
+            def inode_hw_monitoring(self, value):
+                self._value["enable"] = value
+
+        class CliConfigRollBack(object):
+            def __init__(self):
+                self._value = {"enable" : bool()}
+
+            @property
+            def cli_config_rollback(self):
+                return self._value
+
+            @cli_config_rollback.setter
+            def cli_config_rollback(self, value):
+                self._value["enable"] = value
+
     class Cluster(object):
         def __init__(self, payload):
 
@@ -1579,6 +1618,11 @@ class resourcePaylod(object):
                 setattr(containerTimeZoneObj, 'container_timezone', payload['container_timezone'])
                 self.container_timezone = getattr(containerTimeZoneObj, 'container_timezone')
 
+            upgradePolicyObj = resourcePaylod.UpgradePolicy.Channel()
+            if 'policy' in payload and payload['policy'] is not None:
+                setattr(upgradePolicyObj, 'policy', payload['policy'])
+                self.channel = getattr(upgradePolicyObj, 'policy')
+
         class ClusterName(object):
             def __init__(self):
                 self._value = str()
@@ -1722,3 +1766,22 @@ class resourcePaylod(object):
                              payload['command'] == "mgmt_ip" or
                              payload['command'] == "wan_vlan"):
                 self.action = action
+
+    class UpgradePolicy(object):
+        def __init__(self, payload):
+            upgradePolicyObj = resourcePaylod.UpgradePolicy.Channel()
+            if 'policy' in payload and payload['policy'] is not None:
+                setattr(upgradePolicyObj, 'policy', payload['policy'])
+            self.channel = getattr(upgradePolicyObj, 'policy')
+
+        class Channel(object):
+            def __init__(self):
+                self._channel = str()
+
+            @property
+            def policy(self):
+                return self._channel
+
+            @policy.setter
+            def policy(self, channel):
+                self._channel = channel
